@@ -30,7 +30,6 @@ namespace Sass {
     // it's easier to work with vectors
     std::vector<Env*>      env_stack;
     std::vector<Block*>    block_stack;
-    std::vector<AST_Node*> call_stack;
     std::vector<String*>   property_stack;
     std::vector<Selector_List*> selector_stack;
     std::vector<Backtrace*>backtrace_stack;
@@ -38,12 +37,11 @@ namespace Sass {
 
     Statement* fallback_impl(AST_Node* n);
 
-  private:
-    void expand_selector_list(Selector*, Selector_List* extender);
-
   public:
     Expand(Context&, Env*, Backtrace*);
-    ~Expand() { }
+    virtual ~Expand() { }
+
+    using Operation<Statement*>::operator();
 
     Statement* operator()(Block*);
     Statement* operator()(Ruleset*);
