@@ -5,18 +5,17 @@
 #include <string>
 #include <iostream>
 
-using namespace std;
 using namespace Sass;
 
 Context ctx = Context::Data();
 To_String to_string;
 
-Compound_Selector* selector(string src)
-{ return Parser::from_c_str(src.c_str(), ctx, "", Position()).parse_simple_selector_sequence(); }
+Compound_Selector* selector(std::string src)
+{ return Parser::from_c_str(src.c_str(), ctx, "", Position()).parse_compound_selector(); }
 
-void diff(string s, string t)
+void diff(std::string s, std::string t)
 {
-  cout << s << " - " << t << " = " << selector(s + ";")->minus(selector(t + ";"), ctx)->perform(&to_string) << endl;
+  std::cout << s << " - " << t << " = " << selector(s + ";")->minus(selector(t + ";"), ctx)->perform(&to_string) << std::endl;
 }
 
 int main()
